/*
*********************************************************************************************************
*                                             EXAMPLE CODE
* Example Code to demonstrate uCOS II Example project with PSoC 4 BLE

*********************************************************************************************************
*                                             INCLUDE FILES
*********************************************************************************************************
*/
#include <project.h>
#include  "app_cfg.h"
#include  <bsp.h>
#include  <os.h>
#include  <cpu.h>

#include  <lib_math.h>
#include  <lib_mem.h>


/*
*********************************************************************************************************
*                                            LOCAL VARIABLES
*********************************************************************************************************
*/
                                                                /* ------------------ APP TASK VAR(s) ----------------- */
static  OS_STK      App_TaskStartStk[APP_CFG_TASK_START_STK_SIZE];

                                                                
static  OS_STK      App_Demo_TaskStk[APP_CFG_SENSOR_TASK_STK_SIZE];
static  OS_STK      App_Demo_SwitchStk[80];
static  OS_STK      App_Demo_Sinal_Auto_1_Stk[80];
static  OS_STK      App_Demo_Sinal_Pedestre_1_Stk[80];


                                                               

/*
*********************************************************************************************************
*                                         FUNCTION PROTOTYPES
*********************************************************************************************************
*/

static  void  App_TaskStart      (void *p_arg);
static  void  Switch_Task(void *p_arg);
static  void  Sinal_Auto_1_Task(void *p_arg);
static  void  Sinal_Pedestre_1_Task(void *p_arg);

static  void  App_TaskCreate     (void);
static  void  App_ObjCreate      (void);


void  *switch_queue[1];
OS_EVENT  *switch_task_queue;
uint8 success_flag;

/* Variables to handle the switch press event */
uint8 SwitchPressCount;
uint8 switch_press_flag;

/*******************************************************************************
* Function Name: SwitchDetectISR
****************************************************************************//**
*
* \brief Detects the switch press event based on Pin interrupt. Then updates
* the switch press count
*
* \return 
*  None

*******************************************************************************/

CY_ISR(SwitchDetectISR)
{
    /* Set the switch_press flag and increment the count */
    switch_press_flag=1;
    SwitchPressCount++;
    /* Clear the Pin interrupt */
    Switch_Board_ClearInterrupt();
}

/*******************************************************************************
* Function Name: SendSwitchNotification
****************************************************************************//**
*
* \brief Send the current switch press count as 1 byte notification over BLE
*
* \return 
*  None

*******************************************************************************/


/*******************************************************************************
* Function Name: StackEventHandler
****************************************************************************//**
*
* \brief BLE event handler for various event management
*
* \return 
*  None

*******************************************************************************/

/*
*********************************************************************************************************
*                                                main()
*
* Description : This is the standard entry point for C code.  It is assumed that your code will call
*               main() once you have performed all necessary initialization.
*
* Argument(s) : none
*
* Return(s)   : none
*
* Caller(s)   : Startup Code.
*
* Note(s)     : none.
*********************************************************************************************************
*/

int  main (void)
{
    OS_ERR  os_err;

	CyGlobalIntEnable;
	
    CPU_Init();                                                 /* Initialize the uC/CPU services                       */
	Mem_Init();                                                 /* Initialize Memory Managment Module                   */
    Math_Init();                                                /* Initialize Mathematical Module                       */
    
    BSP_Init();                                                 /* Initialize BSP Functions.                            */
    
    OSInit();                                                   /* Init uC/OS-II.                                       */
    
    Switch_ISR_StartEx(SwitchDetectISR);
    
    OSTaskCreateExt( App_TaskStart,                             /* Create the Start Task                                */
                     0u,
                    &App_TaskStartStk[APP_CFG_TASK_START_STK_SIZE - 1u],
                     APP_CFG_TASK_START_PRIO,
                     APP_CFG_TASK_START_PRIO,
                    &App_TaskStartStk[0u],
                     APP_CFG_TASK_START_STK_SIZE,
                     0u,
                    (OS_TASK_OPT_STK_CHK | OS_TASK_OPT_STK_CLR));

    #if (OS_TASK_NAME_EN > 0u)
        OSTaskNameSet(          APP_CFG_TASK_START_PRIO,
                  (INT8U *)"App Task Start",
                           &os_err);
    #endif

    OSStart();                                                  /* Start multitasking (i.e. give control to uC/OS-II).  */
    
    while (DEF_ON);                                             /* Should Never Get Here.                               */
}


/*
*********************************************************************************************************
*                                          App_TaskStart()
*
* Description : This is an example of a startup task.  As mentioned in the book's text, you MUST
*               initialize the ticker only once multitasking has started.
*
* Argument(s) : p_arg   is the argument passed to 'App_TaskStart()' by 'OSTaskCreate()'.
*
* Return(s)   : none
*
* Caller(s)   : main()
*
* Note(s)     : (1) The first line of code is used to prevent a compiler warning because 'p_arg' is not
*                   used.  The compiler should not generate any code for this statement.
*
*               (2) App_TaskStart Task will manage the RGB LED as well as the Push Button to Turn ON
*                   and OFF the RGB LED.
*********************************************************************************************************
*/

void  App_TaskStart (void *p_arg)
{
    CPU_BOOLEAN  pb_status;
    CPU_BOOLEAN  pb_prev;
    CPU_BOOLEAN  led_status;
        

    (void)p_arg;
    led_status = DEF_OFF;                                       /* Initialize Var(s).                                   */

    BSP_CPU_TickInit();                                         /* Initialize the Tick Interrupt.                       */
                                                                
    #if (OS_TASK_STAT_EN > 0u)
        OSStatInit();                                               /* Determine CPU capacity                               */
    #endif

    #ifdef CPU_CFG_INT_DIS_MEAS_EN
        CPU_IntDisMeasMaxCurReset();
    #endif

    APP_TRACE_INFO(("Creating Kernel Objects...\n\r"));
    App_ObjCreate();                                            /* Create Kernel Objects                                */
    
    APP_TRACE_INFO(("Creating Application Tasks...\n\r"));
    App_TaskCreate();                                           /* Create Application Tasks.                            */
    
     
    while (DEF_TRUE) {                                          /* Task body, always written as an infinite loop.       */
        
        /* Base Task Update rate of 100 ms */
        OSTimeDlyHMSM(0u, 0u, 0u, 100u);
    }
}


/*
*********************************************************************************************************
*                                          App_TaskCreate()
*
* Description : Create Application Tasks.
*
* Argument(s) : none
*
* Return(s)   : none
*
* Caller(s)   : AppTaskStart()
*
* Note(s)     : (1) The Following Task(s) were created to test with PSoC 4 BLE
*
*********************************************************************************************************
*/

void  App_TaskCreate (void)
{
    OS_ERR  os_err;
	
    OSTaskCreateExt( Sinal_Auto_1_Task,                       
                     0u,
                    &App_Demo_Sinal_Auto_1_Stk[80],
                     APP_CFG_SINAL_AUTO_1_TASK_PRIO,
                     APP_CFG_SINAL_AUTO_1_TASK_ID,
                    &App_Demo_Sinal_Auto_1_Stk[0u],
                     80,
                     0u,
                    (OS_TASK_OPT_STK_CHK | OS_TASK_OPT_STK_CLR));
    
     OSTaskCreateExt( Sinal_Pedestre_1_Task,                       /* Task that Manages Temp, Accel & Ambient Sensors.     */
                     0u,
                    &App_Demo_Sinal_Pedestre_1_Stk[80],
                     APP_CFG_SINAL_PEDESTRE_1_TASK_PRIO,
                     APP_CFG_SINAL_PEDESTRE_1_TASK_ID,
                    &App_Demo_Sinal_Pedestre_1_Stk[0u],
                     80,
                     0u,
                    (OS_TASK_OPT_STK_CHK | OS_TASK_OPT_STK_CLR));
    
	OSTaskCreateExt( Switch_Task,                       /* Task that Manages Temp, Accel & Ambient Sensors.     */
                     0u,
                    &App_Demo_SwitchStk[80],
                     APP_CFG_SWITCH_TASK_PRIO,
                     APP_CFG_SWITCH_TASK_ID,
                    &App_Demo_SwitchStk[0u],
                     80,
                     0u,
                    (OS_TASK_OPT_STK_CHK | OS_TASK_OPT_STK_CLR));

#if (OS_TASK_NAME_EN > 0u)
    OSTaskNameSet(          APP_CFG_SINAL_AUTO_1_TASK_PRIO,
                  (INT8U *)"Demo: Task",
                           &os_err);
#endif

	switch_task_queue= OSQCreate(switch_queue,1);
}


/*
*********************************************************************************************************
*                                          App_ObjCreate()
*
* Description : Create Application Kernel Objects Tasks.
*
* Argument(s) : none
*
* Return(s)   : none
*
* Caller(s)   : AppTaskStart()
*
* Note(s)     : none.
*********************************************************************************************************
*/

void  App_ObjCreate (void)
{
    
}


/*
*********************************************************************************************************
*********************************************************************************************************
*                                             LOCAL TASKS
*********************************************************************************************************
*********************************************************************************************************
*/

/*******************************************************************************
* Function Name: BLE_Task
****************************************************************************//**
*
* \brief BLE Task Definition
*
* \return 
*  None

*******************************************************************************/

/*******************************************************************************
* Function Name: Switch_Task
****************************************************************************//**
*
* \brief Switch Task Definition
*
* \return 
*  None

*******************************************************************************/

void  Sinal_Auto_1_Task (void *p_arg)
{
	OS_ERR os_err;
	INT8U sinal_auto_1_status_return;

		
	while(1)
	{
        RED_1_Write(1);
        YELLOW_1_Write(1);
        GREEN_1_Write(0);
		OSTimeDly(45000);
       
        RED_1_Write(1);
        YELLOW_1_Write(0);
        GREEN_1_Write(1);
        OSTimeDly(5000);
        
        RED_1_Write(0);
        YELLOW_1_Write(1);
        GREEN_1_Write(1);
        OSTimeDly(50000);
        /* Switch Task Update rate of 100 ms */
		OSTimeDlyHMSM(0u, 0u, 0u, 100u);
	}
}

void  Sinal_Pedestre_1_Task (void *p_arg)
{
    OS_ERR os_err;
	INT8U sinal_pedestre_1_status_return;
    
    while(1)
    {
     RED_P_1_Write(1);
     GREEN_P_1_Write(0);
     OSTimeDly(50000);
    
     RED_P_1_Write(0);
     GREEN_P_1_Write(1);
     OSTimeDly(50000);
     OSTimeDlyHMSM(0u, 0u, 0u, 100u);
    }
 
}

void  Switch_Task (void *p_arg)
{
	OS_ERR os_err;
	INT8U switch_status_return;

		
	while(1)
	{
        /* Check if there is a switch press */
		if(switch_press_flag)
        {
			switch_press_flag=0;
            GREEN_P_1_Write(0);
		
            /* Add the data to the Queue so that BLE Task can use it */
			switch_status_return=OSQPost(switch_task_queue,&SwitchPressCount);
			
			if(switch_status_return==OS_ERR_NONE)
			{
				success_flag=1;
			}
			
		}
		
        /* Switch Task Update rate of 100 ms */
		OSTimeDlyHMSM(0u, 0u, 0u, 100u);
	}
}